-- Priority List 3
-- by Jadya
-- EU-Well of Eternity

local addonName, addonTable = ...
local L = addonTable.L
local T = addonTable.T

local addon = PriorityList
local menus = addon.MenuFunctions
local items = addon.ItemFunctions
local chars = addon.CharFunctions

local tx_cross   = "Interface\\RaidFrame\\ReadyCheck-NotReady"
local tab_textures = T.EJ_Lists

local playername = UnitName("player")
local tooltip, tab_button
local active = false
local sel_list = 1
local sel_difficulty = 1

local function refreshTooltip()
 if not active then
  tooltip:Hide()
  return
 end

 tooltip:ClearLines()
 tooltip:AddLine(playername)
 if not PLWish_List[playername] then 
  tooltip:AddLine(L["nolist"])
 else
  local t = PLWish_List[playername][sel_difficulty].lists[sel_list]
  tooltip:AddDoubleLine(L["list"], L["list"..sel_list])
  tooltip:AddDoubleLine(L["difficulty"], L["difficulty"..sel_difficulty])
  tooltip:AddDoubleLine(ITEMS.." #", #t)
 end
 tooltip:Show()
end

local function refreshLayers()
 local buttons = EncounterJournalEncounterFrameInfoLootScrollFrame.buttons
 
 if PLWish_List[playername] then 
  for i = 1,#buttons do
   local itemID = buttons[i].itemID
   local t = PLWish_List[playername][sel_difficulty].lists[sel_list]
   local icon = _G["EncounterJournalEncounterFrameInfoLootScrollFrameButton"..i.."Icon"]
   itemID = addon:Item2Token(itemID)
   if active and tContains(t, itemID) then
    icon:SetVertexColor(0,1,0,1)
   else
    icon:SetVertexColor(1,1,1,1)
   end
  end
 end

 refreshTooltip()
end

local function setActive(flag)
 if flag then
  active = true
  tab_button.tex_list:SetTexture(tab_textures[sel_list])
  tab_button:LockHighlight()
  tooltip:SetOwner(tab_button, "ANCHOR_RIGHT")
 else
  active = false
  tab_button:UnlockHighlight()
  tab_button.tex_list:SetTexture(tx_cross)
 end
 refreshLayers()
end

local function tabOnClick(self, button)

 if active and button ~= "RightButton" then
  sel_list = sel_list + 1
  if sel_list > 3 then
   sel_list = 1
  end
 end
 setActive(button ~= "RightButton")

 if active then
  EncounterJournal_TabClicked(self)
 end

 refreshLayers()
end

local function instanceOnClick(instanceID)
 if tContains(addon.instanceIDs, instanceID) then
  tab_button:Show()
 else
  tab_button:Hide()
  setActive(false)
 end
end

local function lootOnClick(self, button)
 if not active then return end

 local diff = items:GetDifficulty(self.link)
 if button == "LeftButton" then
  chars:AddItem(playername, self.itemID, sel_list, diff, true)
 elseif button == "RightButton" then
  chars:DeleteItem(playername, self.itemID, sel_list, diff, true)
 end
 refreshLayers()
end

addon.eventhandler:RegisterEvent("ADDON_LOADED")
function addon.eventhandler.ADDON_LOADED(...)
 if ... == "Blizzard_EncounterJournal" then  
  local f = CreateFrame("Button", "PLEJTabButton", EncounterJournal, "EncounterTabTemplate")
  f:RegisterForClicks("LeftButtonUp", "RightButtonUp")
  f:SetPoint("BOTTOMLEFT", EncounterJournal, "BOTTOMRIGHT", -18, 0)
  f:SetID(2)
  f.tooltip = addonName
  f:SetScript("OnClick", tabOnClick)
  f:SetText("Mainspec")
  f.tex_list = f:CreateTexture(nil, "OVERLAY")
  f.tex_list:SetSize(32,32)
  f.tex_list:SetPoint("CENTER")
  f.tex_list:SetTexture(tx_cross)
  f:Hide()
  tab_button = f
  local buttons = EncounterJournalEncounterFrameInfoLootScrollFrame.buttons
  for i = 1,#buttons do
   buttons[i]:HookScript("OnMouseUp", lootOnClick)
  end
  hooksecurefunc("EncounterJournal_DisplayInstance", instanceOnClick)
  hooksecurefunc("EncounterJournal_LootUpdate", refreshLayers)
  EncounterJournalEncounterFrameInfoLootScrollFrameScrollBar:HookScript("OnValueChanged", refreshLayers)
  
  -- list preview tooltip
  f = CreateFrame("GameTooltip", "PLEJPreviewTooltip", tab_button, "GameTooltipTemplate")
  f:Hide()
  tooltip = f
 end
end

addon.eventhandler:RegisterEvent("EJ_DIFFICULTY_UPDATE")
function addon.eventhandler.EJ_DIFFICULTY_UPDATE(...)
 local diff = ... - 13
 if diff < 1 or diff > 3 then diff = 1 end
 sel_difficulty = diff
 -- refreshLayers() -- the LootUpdate hook should do the trick
end